//--------------------------------------------------------------------
// TUCN, Computer Science Department
// Input/Output Systems and Peripheral Devices
//--------------------------------------------------------------------
// http://users.utcluj.ro/~baruch/en/pages/teaching/inputoutput-systems/laboratory.php
//--------------------------------------------------------------------
// File:		GetText-e.cpp
// Date:		18.08.2005
// Modified:	25.02.2009
//--------------------------------------------------------------------
// Example for reading the text from an editing window
//--------------------------------------------------------------------
// - Win32 API functions used:
//   GetWindowText, GetWindowTextLength, GlobalAlloc, GlobalFree,
//   MessageBox
//--------------------------------------------------------------------
// - Operating system: Microsoft Windows 2000/XP
// - Compiler: Microsoft Visual Studio 2008
//--------------------------------------------------------------------

#include <windows.h>

//--------------------------------------------------------------------
// Function GetText
//--------------------------------------------------------------------
//
// Function:	Reads the text from an editing window, stores it 
//				in a buffer, and displays the first 40 characters 
//				from the buffer  
//
// Parameters:	hDisplay - Handle to the editing window
//
// Returns:		0 - Operation completed successfully
//				1 - The window has not been created or there are 
//				    no characters in the window
//				2 - Memory allocation error
//
//--------------------------------------------------------------------

int GetText (HWND hDisplay)
{
	DWORD dwTextLen;
	LPSTR pszBuffer;
	char szBuffer [41];			// buffer for displaying characters

	if (hDisplay == NULL) {
		MessageBox (NULL, "The editing window has not been created!",
					"IOS Application", MB_OK | MB_ICONEXCLAMATION);
		return 1;
	}
	dwTextLen = GetWindowTextLength (hDisplay);
								// determine the length of text in the window
	if (dwTextLen == 0) {
		MessageBox (hDisplay, "There are no characters in the window!",
					"IOS Application", MB_OK | MB_ICONEXCLAMATION);
		return 1;
	}
	pszBuffer = (LPSTR) GlobalAlloc (GPTR, dwTextLen + 1);
								// allocate memory for the buffer
	if (pszBuffer == NULL) {
		MessageBox (hDisplay, "Memory allocation error",
					"IOS Application", MB_OK | MB_ICONERROR);
		return 2;
	}
	GetWindowText (hDisplay, pszBuffer, dwTextLen);
								// transfer the characters to the buffer
	strncpy_s (szBuffer, pszBuffer, 40);
								// copy 40 characters to be displayed
	szBuffer [40] = '\0';		// add the terminating character
	MessageBox (hDisplay, szBuffer,
				"The first 40 characters from the buffer:", MB_OK);
	GlobalFree (pszBuffer);
	return 0;
}